@@ -1,22 +1,50 @@
 import argparse
 
+from .formats import RegexFormatBehavior
+
 
 # support passing through an argparser class to support tests
 def get_parser(cls=None):
-    parser = cls() if cls is not None else argparse.ArgumentParser()
+    parser_cls = cls if cls is not None else argparse.ArgumentParser
+    parser = parser_cls(
+        description="""\
+Check JSON and YAML files against a JSON Schema.
+
+The schema is specified either with '--schemafile' or with '--builtin-schema'.
+
+'check-jsonschema' supports and checks the following formats by default:
+  date, email, ipv4, regex, uuid
+
+For the "regex" format, there are multiple modes which can be specified with
+'--format-regex':
+    default  |  best effort check
+    disabled |  do not check the regex format
+    python   |  check that the string is a valid python regex
+
+The following values are valid for `--builtin-schema` and `--failover-builtin-schema`:
+  vendor.azure-pipelines
+  vendor.github-actions
+  vendor.github-workflows
+  vendor.travis
+  vendor.readthedocs
+  vendor.renovate
+  github-workflows-require-timeout
+
+""",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     parser.add_argument(
         "--schemafile",
         help=(
-            "The path to a file containing the jsonschema to use or an "
+            "The path to a file containing the JSON Schema to use or an "
             "HTTP(S) URI for the schema. If a remote file is used, "
-            "it will be downloaded and cached locally based on mtime. "
-            "This option is required unless --builtin-schema is passed."
+            "it will be downloaded and cached locally based on mtime."
         ),
     )
     parser.add_argument(
         "--builtin-schema",
         help=(
-            "The name of an internal schema to use for `--schemafile`. "
+            "The name of an internal schema to use for '--schemafile'. "
             "Schema names can be found in project documentation."
         ),
     )
@@ -24,7 +52,8 @@ def get_parser(cls=None):
         "--failover-builtin-schema",
         help=(
             "Failover to a specific builtin schema if the schemafile is remote and "
-            "cannot be fetched."
+            "cannot be fetched. "
+            "Schema names can be found in project documentation."
         ),
         type=str.lower,
     )
@@ -38,10 +67,17 @@ def get_parser(cls=None):
         "--disable-format",
         action="store_true",
         default=False,
-        help="Disable all format checks in the schema. "
-        "Because JSON Schema does not require that the format property do any "
-        "validation, files which validate with other tools may fail to validate "
-        "without this flag.",
+        help="Disable all format checks in the schema.",
+    )
+    parser.add_argument(
+        "--format-regex",
+        help=(
+            "Set the mode of format validation for regexes. "
+            "If '--disable-format' is used, this option has no effect."
+        ),
+        type=str.lower,
+        default=RegexFormatBehavior.default.value,
+        choices=[x.value for x in RegexFormatBehavior],
     )
     parser.add_argument(
         "--cache-filename",
@@ -84,4 +120,5 @@ def parse_args(args=None, cls=None):
             parser.error(
                 "--failover-builtin-schema is incompatible with --builtin-schema"
             )
+    args.format_regex = RegexFormatBehavior(args.format_regex)
     return args
